Class: Google::Cloud::HypercomputeCluster::V1beta::DeleteClusterRequest

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/hypercomputecluster/v1beta/hypercompute_cluster.rb

Overview

Request message for DeleteCluster.

Instance Attribute Summary collapse

Instance Attribute Details

#name::String

Returns Required. Name of the cluster to delete, in the format projects/{project}/locations/{location}/clusters/{cluster}.

Returns:

  • (::String)

    Required. Name of the cluster to delete, in the format projects/{project}/locations/{location}/clusters/{cluster}.



238
239
240
241
# File 'proto_docs/google/cloud/hypercomputecluster/v1beta/hypercompute_cluster.rb', line 238

class DeleteClusterRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#request_id::String

Returns Optional. A unique identifier for this request. A random UUID is recommended. This request is idempotent if and only if request_id is provided.

Returns:

  • (::String)

    Optional. A unique identifier for this request. A random UUID is recommended. This request is idempotent if and only if request_id is provided.



238
239
240
241
# File 'proto_docs/google/cloud/hypercomputecluster/v1beta/hypercompute_cluster.rb', line 238

class DeleteClusterRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end