Class: Google::Cloud::HypercomputeCluster::V1beta::ExistingFilestoreConfig

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/hypercomputecluster/v1beta/hypercompute_cluster.rb

Overview

When set in a StorageResourceConfig, indicates that an existing Filestore instance should be imported.

Instance Attribute Summary collapse

Instance Attribute Details

#filestore::String

Returns Required. Immutable. Name of the Filestore instance to import, in the format projects/{project}/locations/{location}/instances/{instance}.

Returns:

  • (::String)

    Required. Immutable. Name of the Filestore instance to import, in the format projects/{project}/locations/{location}/instances/{instance}



513
514
515
516
# File 'proto_docs/google/cloud/hypercomputecluster/v1beta/hypercompute_cluster.rb', line 513

class ExistingFilestoreConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end