Class: Google::Cloud::HypercomputeCluster::V1beta::ExistingLustreConfig

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/hypercomputecluster/v1beta/hypercompute_cluster.rb

Overview

When set in a StorageResourceConfig, indicates that an existing Managed Lustre instance should be imported.

Instance Attribute Summary collapse

Instance Attribute Details

#lustre::String

Returns Required. Immutable. Name of the Managed Lustre instance to import, in the format projects/{project}/locations/{location}/instances/{instance}.

Returns:

  • (::String)

    Required. Immutable. Name of the Managed Lustre instance to import, in the format projects/{project}/locations/{location}/instances/{instance}



642
643
644
645
# File 'proto_docs/google/cloud/hypercomputecluster/v1beta/hypercompute_cluster.rb', line 642

class ExistingLustreConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end