Class: Google::Cloud::HypercomputeCluster::V1beta::FilestoreReference

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/hypercomputecluster/v1beta/hypercompute_cluster.rb

Overview

A reference to a Filestore instance.

Instance Attribute Summary collapse

Instance Attribute Details

#filestore::String (readonly)

Returns Output only. Name of the Filestore instance, in the format projects/{project}/locations/{location}/instances/{instance}.

Returns:

  • (::String)

    Output only. Name of the Filestore instance, in the format projects/{project}/locations/{location}/instances/{instance}



365
366
367
368
# File 'proto_docs/google/cloud/hypercomputecluster/v1beta/hypercompute_cluster.rb', line 365

class FilestoreReference
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end