Class: Google::Cloud::HypercomputeCluster::V1beta::GcsAutoclassConfig
- Inherits:
-
Object
- Object
- Google::Cloud::HypercomputeCluster::V1beta::GcsAutoclassConfig
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/hypercomputecluster/v1beta/hypercompute_cluster.rb
Overview
Message describing Google Cloud Storage autoclass configuration
Defined Under Namespace
Modules: TerminalStorageClass
Instance Attribute Summary collapse
-
#enabled ⇒ ::Boolean
Required.
-
#terminal_storage_class ⇒ ::Google::Cloud::HypercomputeCluster::V1beta::GcsAutoclassConfig::TerminalStorageClass
Optional.
Instance Attribute Details
#enabled ⇒ ::Boolean
Returns Required. Enables Auto-class feature.
574 575 576 577 578 579 580 581 582 583 |
# File 'proto_docs/google/cloud/hypercomputecluster/v1beta/hypercompute_cluster.rb', line 574 class GcsAutoclassConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Terminal storage class types of the autoclass bucket module TerminalStorageClass # Unspecified terminal storage class TERMINAL_STORAGE_CLASS_UNSPECIFIED = 0 end end |
#terminal_storage_class ⇒ ::Google::Cloud::HypercomputeCluster::V1beta::GcsAutoclassConfig::TerminalStorageClass
Returns Optional. Terminal storage class of the autoclass bucket.
574 575 576 577 578 579 580 581 582 583 |
# File 'proto_docs/google/cloud/hypercomputecluster/v1beta/hypercompute_cluster.rb', line 574 class GcsAutoclassConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Terminal storage class types of the autoclass bucket module TerminalStorageClass # Unspecified terminal storage class TERMINAL_STORAGE_CLASS_UNSPECIFIED = 0 end end |