Class: Google::Cloud::HypercomputeCluster::V1beta::GetClusterRequest

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/hypercomputecluster/v1beta/hypercompute_cluster.rb

Overview

Request message for GetCluster.

Instance Attribute Summary collapse

Instance Attribute Details

#name::String

Returns Required. Name of the cluster to retrieve, in the format projects/{project}/locations/{location}/clusters/{cluster}.

Returns:

  • (::String)

    Required. Name of the cluster to retrieve, in the format projects/{project}/locations/{location}/clusters/{cluster}.



178
179
180
181
# File 'proto_docs/google/cloud/hypercomputecluster/v1beta/hypercompute_cluster.rb', line 178

class GetClusterRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end