Class: Google::Cloud::HypercomputeCluster::V1beta::ListClustersResponse

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/hypercomputecluster/v1beta/hypercompute_cluster.rb

Overview

Response message for ListClusters.

Instance Attribute Summary collapse

Instance Attribute Details

#clusters::Array<::Google::Cloud::HypercomputeCluster::V1beta::Cluster>

Returns Clusters in the specified location.

Returns:



167
168
169
170
# File 'proto_docs/google/cloud/hypercomputecluster/v1beta/hypercompute_cluster.rb', line 167

class ListClustersResponse
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#next_page_token::String

Returns A token that can be sent as page_token to retrieve the next page. If this field is absent, there are no subsequent pages.

Returns:

  • (::String)

    A token that can be sent as page_token to retrieve the next page. If this field is absent, there are no subsequent pages.



167
168
169
170
# File 'proto_docs/google/cloud/hypercomputecluster/v1beta/hypercompute_cluster.rb', line 167

class ListClustersResponse
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#unreachable::Array<::String>

Returns Locations that could not be reached.

Returns:

  • (::Array<::String>)

    Locations that could not be reached.



167
168
169
170
# File 'proto_docs/google/cloud/hypercomputecluster/v1beta/hypercompute_cluster.rb', line 167

class ListClustersResponse
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end