Class: Google::Cloud::HypercomputeCluster::V1beta::LustreReference

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/hypercomputecluster/v1beta/hypercompute_cluster.rb

Overview

A reference to a Managed Lustre instance.

Instance Attribute Summary collapse

Instance Attribute Details

#lustre::String (readonly)

Returns Output only. Name of the Managed Lustre instance, in the format projects/{project}/locations/{location}/instances/{instance}.

Returns:

  • (::String)

    Output only. Name of the Managed Lustre instance, in the format projects/{project}/locations/{location}/instances/{instance}



386
387
388
389
# File 'proto_docs/google/cloud/hypercomputecluster/v1beta/hypercompute_cluster.rb', line 386

class LustreReference
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end