Class: Google::Cloud::HypercomputeCluster::V1beta::NetworkReference

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/hypercomputecluster/v1beta/hypercompute_cluster.rb

Overview

A reference to a VPC network in Google Compute Engine.

Instance Attribute Summary collapse

Instance Attribute Details

#network::String (readonly)

Returns Output only. Name of the network, in the format projects/{project}/global/networks/{network}.

Returns:

  • (::String)

    Output only. Name of the network, in the format projects/{project}/global/networks/{network}.



271
272
273
274
# File 'proto_docs/google/cloud/hypercomputecluster/v1beta/hypercompute_cluster.rb', line 271

class NetworkReference
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#subnetwork::String (readonly)

Returns Output only. Name of the particular subnetwork being used by the cluster, in the format projects/{project}/regions/{region}/subnetworks/{subnetwork}.

Returns:

  • (::String)

    Output only. Name of the particular subnetwork being used by the cluster, in the format projects/{project}/regions/{region}/subnetworks/{subnetwork}.



271
272
273
274
# File 'proto_docs/google/cloud/hypercomputecluster/v1beta/hypercompute_cluster.rb', line 271

class NetworkReference
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end