Class: Google::Cloud::HypercomputeCluster::V1beta::NewFlexStartInstancesConfig

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/hypercomputecluster/v1beta/hypercompute_cluster.rb

Overview

When set in a ComputeResourceConfig, indicates that VM instances should be created using Flex Start.

Instance Attribute Summary collapse

Instance Attribute Details

#machine_type::String

Returns Required. Immutable. Name of the Compute Engine machine type to use, e.g. n2-standard-2.

Returns:

  • (::String)

    Required. Immutable. Name of the Compute Engine machine type to use, e.g. n2-standard-2.



759
760
761
762
# File 'proto_docs/google/cloud/hypercomputecluster/v1beta/hypercompute_cluster.rb', line 759

class NewFlexStartInstancesConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#max_duration::Google::Protobuf::Duration

Returns Required. Immutable. Specifies the time limit for created instances. Instances will be terminated at the end of this duration.

Returns:

  • (::Google::Protobuf::Duration)

    Required. Immutable. Specifies the time limit for created instances. Instances will be terminated at the end of this duration.



759
760
761
762
# File 'proto_docs/google/cloud/hypercomputecluster/v1beta/hypercompute_cluster.rb', line 759

class NewFlexStartInstancesConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#zone::String

Returns Required. Immutable. Name of the zone in which VM instances should run, e.g., us-central1-a. Must be in the same region as the cluster, and must match the zone of any other resources specified in the cluster.

Returns:

  • (::String)

    Required. Immutable. Name of the zone in which VM instances should run, e.g., us-central1-a. Must be in the same region as the cluster, and must match the zone of any other resources specified in the cluster.



759
760
761
762
# File 'proto_docs/google/cloud/hypercomputecluster/v1beta/hypercompute_cluster.rb', line 759

class NewFlexStartInstancesConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end