Class: Google::Cloud::HypercomputeCluster::V1beta::NewReservedInstancesConfig

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/hypercomputecluster/v1beta/hypercompute_cluster.rb

Overview

When set in a ComputeResourceConfig, indicates that VM instances should be created from a reservation.

Instance Attribute Summary collapse

Instance Attribute Details

#reservation::String

Returns Optional. Immutable. Name of the reservation from which VM instances should be created, in the format projects/{project}/zones/{zone}/reservations/{reservation}.

Returns:

  • (::String)

    Optional. Immutable. Name of the reservation from which VM instances should be created, in the format projects/{project}/zones/{zone}/reservations/{reservation}.



736
737
738
739
# File 'proto_docs/google/cloud/hypercomputecluster/v1beta/hypercompute_cluster.rb', line 736

class NewReservedInstancesConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end