Class: Google::Cloud::HypercomputeCluster::V1beta::NewSpotInstancesConfig
- Inherits:
-
Object
- Object
- Google::Cloud::HypercomputeCluster::V1beta::NewSpotInstancesConfig
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/hypercomputecluster/v1beta/hypercompute_cluster.rb
Overview
When set in a ComputeResourceConfig, indicates that spot VM instances should be created.
Instance Attribute Summary collapse
-
#machine_type ⇒ ::String
Required.
-
#zone ⇒ ::String
Required.
Instance Attribute Details
#machine_type ⇒ ::String
Returns Required. Immutable. Name of the Compute Engine machine
type to use, e.g.
n2-standard-2.
722 723 724 725 |
# File 'proto_docs/google/cloud/hypercomputecluster/v1beta/hypercompute_cluster.rb', line 722 class NewSpotInstancesConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#zone ⇒ ::String
Returns Required. Immutable. Name of the zone in which VM instances should run,
e.g., us-central1-a. Must be in the same region as the cluster, and must
match the zone of any other resources specified in the cluster.
722 723 724 725 |
# File 'proto_docs/google/cloud/hypercomputecluster/v1beta/hypercompute_cluster.rb', line 722 class NewSpotInstancesConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |