Class: Google::Cloud::HypercomputeCluster::V1beta::SlurmNodeSet

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/hypercomputecluster/v1beta/hypercompute_cluster.rb

Overview

Configuration for Slurm nodesets in the cluster. Nodesets are groups of compute nodes used by Slurm that are responsible for running workloads submitted to the cluster.

Instance Attribute Summary collapse

Instance Attribute Details

#compute_id::String

Returns Optional. ID of the compute resource on which this nodeset will run. Must match a key in the cluster's compute_resources.

Returns:

  • (::String)

    Optional. ID of the compute resource on which this nodeset will run. Must match a key in the cluster's compute_resources.



865
866
867
868
# File 'proto_docs/google/cloud/hypercomputecluster/v1beta/hypercompute_cluster.rb', line 865

class SlurmNodeSet
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#compute_instance::Google::Cloud::HypercomputeCluster::V1beta::ComputeInstanceSlurmNodeSet

Returns Optional. If set, indicates that the nodeset should be backed by Compute Engine instances.

Returns:



865
866
867
868
# File 'proto_docs/google/cloud/hypercomputecluster/v1beta/hypercompute_cluster.rb', line 865

class SlurmNodeSet
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#id::String

Returns Required. Identifier for the nodeset, which allows it to be referenced by partitions. Must conform to RFC-1034 (lower-case, alphanumeric, and at most 63 characters).

Returns:

  • (::String)

    Required. Identifier for the nodeset, which allows it to be referenced by partitions. Must conform to RFC-1034 (lower-case, alphanumeric, and at most 63 characters).



865
866
867
868
# File 'proto_docs/google/cloud/hypercomputecluster/v1beta/hypercompute_cluster.rb', line 865

class SlurmNodeSet
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#max_dynamic_node_count::Integer

Returns Optional. Controls how many additional nodes a cluster can bring online to handle workloads. Set this value to enable dynamic node creation and limit the number of additional nodes the cluster can bring online. Leave empty if you do not want the cluster to create nodes dynamically, and instead rely only on static nodes.

Returns:

  • (::Integer)

    Optional. Controls how many additional nodes a cluster can bring online to handle workloads. Set this value to enable dynamic node creation and limit the number of additional nodes the cluster can bring online. Leave empty if you do not want the cluster to create nodes dynamically, and instead rely only on static nodes.



865
866
867
868
# File 'proto_docs/google/cloud/hypercomputecluster/v1beta/hypercompute_cluster.rb', line 865

class SlurmNodeSet
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#static_node_count::Integer

Returns Optional. Number of nodes to be statically created for this nodeset. The cluster will attempt to ensure that at least this many nodes exist at all times.

Returns:

  • (::Integer)

    Optional. Number of nodes to be statically created for this nodeset. The cluster will attempt to ensure that at least this many nodes exist at all times.



865
866
867
868
# File 'proto_docs/google/cloud/hypercomputecluster/v1beta/hypercompute_cluster.rb', line 865

class SlurmNodeSet
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#storage_configs::Array<::Google::Cloud::HypercomputeCluster::V1beta::StorageConfig>

Returns Optional. How [storage resources][google.cloud.hypercomputecluster.v1beta.StorageResource] should be mounted on each compute node.

Returns:



865
866
867
868
# File 'proto_docs/google/cloud/hypercomputecluster/v1beta/hypercompute_cluster.rb', line 865

class SlurmNodeSet
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end