Class: Google::Cloud::HypercomputeCluster::V1beta::SlurmOrchestrator

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/hypercomputecluster/v1beta/hypercompute_cluster.rb

Overview

When set in Orchestrator, indicates that the cluster should use Slurm as the orchestrator.

Instance Attribute Summary collapse

Instance Attribute Details

#default_partition::String

Returns Optional. Default partition to use for submitted jobs that do not explicitly specify a partition. Required if and only if there is more than one partition, in which case it must match the id of one of the partitions.

Returns:

  • (::String)

    Optional. Default partition to use for submitted jobs that do not explicitly specify a partition. Required if and only if there is more than one partition, in which case it must match the id of one of the partitions.



825
826
827
828
# File 'proto_docs/google/cloud/hypercomputecluster/v1beta/hypercompute_cluster.rb', line 825

class SlurmOrchestrator
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#epilog_bash_scripts::Array<::String>

Returns Optional. Slurm epilog scripts, which will be executed by compute nodes whenever a node finishes running a job. Values must not be empty.

Returns:

  • (::Array<::String>)

    Optional. Slurm epilog scripts, which will be executed by compute nodes whenever a node finishes running a job. Values must not be empty.



825
826
827
828
# File 'proto_docs/google/cloud/hypercomputecluster/v1beta/hypercompute_cluster.rb', line 825

class SlurmOrchestrator
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#login_nodes::Google::Cloud::HypercomputeCluster::V1beta::SlurmLoginNodes

Returns Required. Configuration for login nodes, which allow users to access the cluster over SSH.

Returns:



825
826
827
828
# File 'proto_docs/google/cloud/hypercomputecluster/v1beta/hypercompute_cluster.rb', line 825

class SlurmOrchestrator
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#node_sets::Array<::Google::Cloud::HypercomputeCluster::V1beta::SlurmNodeSet>

Returns Required. Configuration of Slurm nodesets, which define groups of compute resources that can be used by Slurm. At least one compute node is required.

Returns:



825
826
827
828
# File 'proto_docs/google/cloud/hypercomputecluster/v1beta/hypercompute_cluster.rb', line 825

class SlurmOrchestrator
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#partitions::Array<::Google::Cloud::HypercomputeCluster::V1beta::SlurmPartition>

Returns Required. Configuration of Slurm partitions, which group one or more nodesets. Acts as a queue against which jobs can be submitted. At least one partition is required.

Returns:



825
826
827
828
# File 'proto_docs/google/cloud/hypercomputecluster/v1beta/hypercompute_cluster.rb', line 825

class SlurmOrchestrator
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#prolog_bash_scripts::Array<::String>

Returns Optional. Slurm prolog scripts, which will be executed by compute nodes before a node begins running a new job. Values must not be empty.

Returns:

  • (::Array<::String>)

    Optional. Slurm prolog scripts, which will be executed by compute nodes before a node begins running a new job. Values must not be empty.



825
826
827
828
# File 'proto_docs/google/cloud/hypercomputecluster/v1beta/hypercompute_cluster.rb', line 825

class SlurmOrchestrator
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end