Class: Google::Cloud::HypercomputeCluster::V1beta::SlurmPartition

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/hypercomputecluster/v1beta/hypercompute_cluster.rb

Overview

Configuration for Slurm partitions in the cluster. Partitions are groups of nodesets, and are how clients specify where their workloads should be run.

Instance Attribute Summary collapse

Instance Attribute Details

#id::String

Returns Required. ID of the partition, which is how users will identify it. Must conform to RFC-1034 (lower-case, alphanumeric, and at most 63 characters).

Returns:

  • (::String)

    Required. ID of the partition, which is how users will identify it. Must conform to RFC-1034 (lower-case, alphanumeric, and at most 63 characters).



912
913
914
915
# File 'proto_docs/google/cloud/hypercomputecluster/v1beta/hypercompute_cluster.rb', line 912

class SlurmPartition
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#node_set_ids::Array<::String>

Returns Required. IDs of the nodesets that make up this partition. Values must match SlurmNodeSet.id.

Returns:

  • (::Array<::String>)

    Required. IDs of the nodesets that make up this partition. Values must match SlurmNodeSet.id.



912
913
914
915
# File 'proto_docs/google/cloud/hypercomputecluster/v1beta/hypercompute_cluster.rb', line 912

class SlurmPartition
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end