Class: Google::Cloud::HypercomputeCluster::V1beta::StorageConfig

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/hypercomputecluster/v1beta/hypercompute_cluster.rb

Overview

Description of how a [storage resource][google.cloud.hypercomputecluster.v1beta.StorageResource] should be mounted on a VM instance.

Instance Attribute Summary collapse

Instance Attribute Details

#id::String

Returns Required. ID of the storage resource to mount, which must match a key in the cluster's storage_resources.

Returns:

  • (::String)

    Required. ID of the storage resource to mount, which must match a key in the cluster's storage_resources.



989
990
991
992
# File 'proto_docs/google/cloud/hypercomputecluster/v1beta/hypercompute_cluster.rb', line 989

class StorageConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#local_mount::String

Returns Required. A directory inside the VM instance's file system where the storage resource should be mounted (e.g., /mnt/share).

Returns:

  • (::String)

    Required. A directory inside the VM instance's file system where the storage resource should be mounted (e.g., /mnt/share).



989
990
991
992
# File 'proto_docs/google/cloud/hypercomputecluster/v1beta/hypercompute_cluster.rb', line 989

class StorageConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end