Class: Google::Cloud::HypercomputeCluster::V1beta::UpdateClusterRequest

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/hypercomputecluster/v1beta/hypercompute_cluster.rb

Overview

Request message for UpdateCluster.

Instance Attribute Summary collapse

Instance Attribute Details

#cluster::Google::Cloud::HypercomputeCluster::V1beta::Cluster

Returns Required. Cluster to update.

Returns:



222
223
224
225
# File 'proto_docs/google/cloud/hypercomputecluster/v1beta/hypercompute_cluster.rb', line 222

class UpdateClusterRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#request_id::String

Returns Optional. A unique identifier for this request. A random UUID is recommended. This request is idempotent if and only if request_id is provided.

Returns:

  • (::String)

    Optional. A unique identifier for this request. A random UUID is recommended. This request is idempotent if and only if request_id is provided.



222
223
224
225
# File 'proto_docs/google/cloud/hypercomputecluster/v1beta/hypercompute_cluster.rb', line 222

class UpdateClusterRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#update_mask::Google::Protobuf::FieldMask

Returns Optional. Mask specifying which fields in the cluster to update. All paths must be specified explicitly - wildcards are not supported. At least one path must be provided.

Returns:

  • (::Google::Protobuf::FieldMask)

    Optional. Mask specifying which fields in the cluster to update. All paths must be specified explicitly - wildcards are not supported. At least one path must be provided.



222
223
224
225
# File 'proto_docs/google/cloud/hypercomputecluster/v1beta/hypercompute_cluster.rb', line 222

class UpdateClusterRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end