Class: Google::Cloud::HypercomputeCluster::V1beta::ComputeResource
- Inherits:
-
Object
- Object
- Google::Cloud::HypercomputeCluster::V1beta::ComputeResource
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/hypercomputecluster/v1beta/hypercompute_cluster.rb
Overview
A resource defining how virtual machines and accelerators should be provisioned for the cluster.
Instance Attribute Summary collapse
Instance Attribute Details
#config ⇒ ::Google::Cloud::HypercomputeCluster::V1beta::ComputeResourceConfig
Returns Required. Immutable. Configuration for this compute resource, which describes how it should be created at runtime.
653 654 655 656 |
# File 'proto_docs/google/cloud/hypercomputecluster/v1beta/hypercompute_cluster.rb', line 653 class ComputeResource include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |