Class: Google::Cloud::HypercomputeCluster::V1beta::ComputeResourceConfig
- Inherits:
-
Object
- Object
- Google::Cloud::HypercomputeCluster::V1beta::ComputeResourceConfig
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/hypercomputecluster/v1beta/hypercompute_cluster.rb
Overview
Describes how a compute resource should be created at runtime.
Instance Attribute Summary collapse
-
#new_flex_start_instances ⇒ ::Google::Cloud::HypercomputeCluster::V1beta::NewFlexStartInstancesConfig
Optional.
-
#new_on_demand_instances ⇒ ::Google::Cloud::HypercomputeCluster::V1beta::NewOnDemandInstancesConfig
Optional.
-
#new_reserved_instances ⇒ ::Google::Cloud::HypercomputeCluster::V1beta::NewReservedInstancesConfig
Optional.
-
#new_spot_instances ⇒ ::Google::Cloud::HypercomputeCluster::V1beta::NewSpotInstancesConfig
Optional.
Instance Attribute Details
#new_flex_start_instances ⇒ ::Google::Cloud::HypercomputeCluster::V1beta::NewFlexStartInstancesConfig
Returns Optional. Immutable. If set, indicates that this resource should use flex-start VMs.
Note: The following fields are mutually exclusive: new_flex_start_instances, new_on_demand_instances, new_spot_instances, new_reserved_instances. If a field in that set is populated, all other fields in the set will automatically be cleared.
683 684 685 686 |
# File 'proto_docs/google/cloud/hypercomputecluster/v1beta/hypercompute_cluster.rb', line 683 class ComputeResourceConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#new_on_demand_instances ⇒ ::Google::Cloud::HypercomputeCluster::V1beta::NewOnDemandInstancesConfig
Returns Optional. Immutable. If set, indicates that this resource should use on-demand VMs.
Note: The following fields are mutually exclusive: new_on_demand_instances, new_spot_instances, new_reserved_instances, new_flex_start_instances. If a field in that set is populated, all other fields in the set will automatically be cleared.
683 684 685 686 |
# File 'proto_docs/google/cloud/hypercomputecluster/v1beta/hypercompute_cluster.rb', line 683 class ComputeResourceConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#new_reserved_instances ⇒ ::Google::Cloud::HypercomputeCluster::V1beta::NewReservedInstancesConfig
Returns Optional. Immutable. If set, indicates that this resource should use reserved VMs.
Note: The following fields are mutually exclusive: new_reserved_instances, new_on_demand_instances, new_spot_instances, new_flex_start_instances. If a field in that set is populated, all other fields in the set will automatically be cleared.
683 684 685 686 |
# File 'proto_docs/google/cloud/hypercomputecluster/v1beta/hypercompute_cluster.rb', line 683 class ComputeResourceConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#new_spot_instances ⇒ ::Google::Cloud::HypercomputeCluster::V1beta::NewSpotInstancesConfig
Returns Optional. Immutable. If set, indicates that this resource should use spot VMs.
Note: The following fields are mutually exclusive: new_spot_instances, new_on_demand_instances, new_reserved_instances, new_flex_start_instances. If a field in that set is populated, all other fields in the set will automatically be cleared.
683 684 685 686 |
# File 'proto_docs/google/cloud/hypercomputecluster/v1beta/hypercompute_cluster.rb', line 683 class ComputeResourceConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |