Class: Google::Cloud::HypercomputeCluster::V1beta::CreateClusterRequest
- Inherits:
-
Object
- Object
- Google::Cloud::HypercomputeCluster::V1beta::CreateClusterRequest
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/hypercomputecluster/v1beta/hypercompute_cluster.rb
Overview
Request message for CreateCluster.
Instance Attribute Summary collapse
-
#cluster ⇒ ::Google::Cloud::HypercomputeCluster::V1beta::Cluster
Required.
-
#cluster_id ⇒ ::String
Required.
-
#parent ⇒ ::String
Required.
-
#request_id ⇒ ::String
Optional.
Instance Attribute Details
#cluster ⇒ ::Google::Cloud::HypercomputeCluster::V1beta::Cluster
Returns Required. Cluster to create.
202 203 204 205 |
# File 'proto_docs/google/cloud/hypercomputecluster/v1beta/hypercompute_cluster.rb', line 202 class CreateClusterRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#cluster_id ⇒ ::String
Returns Required. ID of the cluster to create. Must conform to RFC-1034 (lower-case, alphanumeric, and at most 63 characters).
202 203 204 205 |
# File 'proto_docs/google/cloud/hypercomputecluster/v1beta/hypercompute_cluster.rb', line 202 class CreateClusterRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#parent ⇒ ::String
Returns Required. Parent location in which the cluster should be created, in the
format projects/{project}/locations/{location}.
202 203 204 205 |
# File 'proto_docs/google/cloud/hypercomputecluster/v1beta/hypercompute_cluster.rb', line 202 class CreateClusterRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#request_id ⇒ ::String
Returns Optional. A unique identifier for this request. A random UUID is
recommended. This request is idempotent if and only if request_id is
provided.
202 203 204 205 |
# File 'proto_docs/google/cloud/hypercomputecluster/v1beta/hypercompute_cluster.rb', line 202 class CreateClusterRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |