Class: Google::Cloud::HypercomputeCluster::V1beta::ExistingNetworkConfig
- Inherits:
-
Object
- Object
- Google::Cloud::HypercomputeCluster::V1beta::ExistingNetworkConfig
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/hypercomputecluster/v1beta/hypercompute_cluster.rb
Overview
When set in a NetworkResourceConfig, indicates that an existing network should be imported.
Instance Attribute Summary collapse
-
#network ⇒ ::String
Required.
-
#subnetwork ⇒ ::String
Required.
Instance Attribute Details
#network ⇒ ::String
Returns Required. Immutable. Name of the network to import, in the format
projects/{project}/global/networks/{network}.
323 324 325 326 |
# File 'proto_docs/google/cloud/hypercomputecluster/v1beta/hypercompute_cluster.rb', line 323 class ExistingNetworkConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#subnetwork ⇒ ::String
Returns Required. Immutable. Particular subnetwork to use, in the format
projects/{project}/regions/{region}/subnetworks/{subnetwork}.
323 324 325 326 |
# File 'proto_docs/google/cloud/hypercomputecluster/v1beta/hypercompute_cluster.rb', line 323 class ExistingNetworkConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |