Class: Google::Cloud::HypercomputeCluster::V1beta::ListClustersRequest
- Inherits:
-
Object
- Object
- Google::Cloud::HypercomputeCluster::V1beta::ListClustersRequest
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/hypercomputecluster/v1beta/hypercompute_cluster.rb
Overview
Request message for ListClusters.
Instance Attribute Summary collapse
-
#filter ⇒ ::String
Optional.
-
#order_by ⇒ ::String
Optional.
-
#page_size ⇒ ::Integer
Optional.
-
#page_token ⇒ ::String
Optional.
-
#parent ⇒ ::String
Required.
Instance Attribute Details
#filter ⇒ ::String
Returns Optional. Filter to apply to the returned results.
150 151 152 153 |
# File 'proto_docs/google/cloud/hypercomputecluster/v1beta/hypercompute_cluster.rb', line 150 class ListClustersRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#order_by ⇒ ::String
Returns Optional. How to order the resulting clusters. Must be one of the following strings:
namename desccreate_timecreate_time desc
If not specified, clusters will be returned in an arbitrary order.
150 151 152 153 |
# File 'proto_docs/google/cloud/hypercomputecluster/v1beta/hypercompute_cluster.rb', line 150 class ListClustersRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#page_size ⇒ ::Integer
Returns Optional. Maximum number of clusters to return. The service may return fewer than this value.
150 151 152 153 |
# File 'proto_docs/google/cloud/hypercomputecluster/v1beta/hypercompute_cluster.rb', line 150 class ListClustersRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#page_token ⇒ ::String
Returns Optional. A page token received from a previous ListClusters call.
Provide this to retrieve the subsequent page. When paginating, all other
parameters provided to ListClusters must match the call that provided the
page token.
150 151 152 153 |
# File 'proto_docs/google/cloud/hypercomputecluster/v1beta/hypercompute_cluster.rb', line 150 class ListClustersRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#parent ⇒ ::String
Returns Required. Parent location of the clusters to list, in the format
projects/{project}/locations/{location}.
150 151 152 153 |
# File 'proto_docs/google/cloud/hypercomputecluster/v1beta/hypercompute_cluster.rb', line 150 class ListClustersRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |