Class: Google::Cloud::HypercomputeCluster::V1beta::NetworkResource
- Inherits:
-
Object
- Object
- Google::Cloud::HypercomputeCluster::V1beta::NetworkResource
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/hypercomputecluster/v1beta/hypercompute_cluster.rb
Overview
A resource representing a network that connects the various components of a cluster together.
Instance Attribute Summary collapse
-
#config ⇒ ::Google::Cloud::HypercomputeCluster::V1beta::NetworkResourceConfig
Immutable.
-
#network ⇒ ::Google::Cloud::HypercomputeCluster::V1beta::NetworkReference
Reference to a network in Google Compute Engine.
Instance Attribute Details
#config ⇒ ::Google::Cloud::HypercomputeCluster::V1beta::NetworkResourceConfig
Returns Immutable. Configuration for this network resource, which describes how it should be created or imported. This field only controls how the network resource is initially created or imported. Subsequent changes to the network resource should be made via the resource's API and will not be reflected in the configuration.
255 256 257 258 |
# File 'proto_docs/google/cloud/hypercomputecluster/v1beta/hypercompute_cluster.rb', line 255 class NetworkResource include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#network ⇒ ::Google::Cloud::HypercomputeCluster::V1beta::NetworkReference
Returns Reference to a network in Google Compute Engine.
255 256 257 258 |
# File 'proto_docs/google/cloud/hypercomputecluster/v1beta/hypercompute_cluster.rb', line 255 class NetworkResource include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |