Class: Google::Cloud::HypercomputeCluster::V1beta::NetworkResourceConfig
- Inherits:
-
Object
- Object
- Google::Cloud::HypercomputeCluster::V1beta::NetworkResourceConfig
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/hypercomputecluster/v1beta/hypercompute_cluster.rb
Overview
Describes how a network resource should be initialized. Each network resource can either be imported from an existing Google Cloud resource or initialized when the cluster is created.
Instance Attribute Summary collapse
-
#existing_network ⇒ ::Google::Cloud::HypercomputeCluster::V1beta::ExistingNetworkConfig
Optional.
-
#new_network ⇒ ::Google::Cloud::HypercomputeCluster::V1beta::NewNetworkConfig
Optional.
Instance Attribute Details
#existing_network ⇒ ::Google::Cloud::HypercomputeCluster::V1beta::ExistingNetworkConfig
Returns Optional. Immutable. If set, indicates that an existing network should be imported.
Note: The following fields are mutually exclusive: existing_network, new_network. If a field in that set is populated, all other fields in the set will automatically be cleared.
291 292 293 294 |
# File 'proto_docs/google/cloud/hypercomputecluster/v1beta/hypercompute_cluster.rb', line 291 class NetworkResourceConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#new_network ⇒ ::Google::Cloud::HypercomputeCluster::V1beta::NewNetworkConfig
Returns Optional. Immutable. If set, indicates that a new network should be created.
Note: The following fields are mutually exclusive: new_network, existing_network. If a field in that set is populated, all other fields in the set will automatically be cleared.
291 292 293 294 |
# File 'proto_docs/google/cloud/hypercomputecluster/v1beta/hypercompute_cluster.rb', line 291 class NetworkResourceConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |