Class: Google::Cloud::HypercomputeCluster::V1beta::NewBucketConfig
- Inherits:
-
Object
- Object
- Google::Cloud::HypercomputeCluster::V1beta::NewBucketConfig
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/hypercomputecluster/v1beta/hypercompute_cluster.rb
Overview
When set in a StorageResourceConfig, indicates that a new Google Cloud Storage bucket should be created.
Defined Under Namespace
Modules: StorageClass
Instance Attribute Summary collapse
-
#autoclass ⇒ ::Google::Cloud::HypercomputeCluster::V1beta::GcsAutoclassConfig
Optional.
-
#bucket ⇒ ::String
Required.
-
#hierarchical_namespace ⇒ ::Google::Cloud::HypercomputeCluster::V1beta::GcsHierarchicalNamespaceConfig
Optional.
-
#storage_class ⇒ ::Google::Cloud::HypercomputeCluster::V1beta::NewBucketConfig::StorageClass
Optional.
Instance Attribute Details
#autoclass ⇒ ::Google::Cloud::HypercomputeCluster::V1beta::GcsAutoclassConfig
Returns Optional. Immutable. If set, indicates that the bucket should use Autoclass.
Note: The following fields are mutually exclusive: autoclass, storage_class. If a field in that set is populated, all other fields in the set will automatically be cleared.
542 543 544 545 546 547 548 549 550 551 552 553 554 555 556 557 558 559 560 561 562 563 564 565 |
# File 'proto_docs/google/cloud/hypercomputecluster/v1beta/hypercompute_cluster.rb', line 542 class NewBucketConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # [Storage class](https://cloud.google.com/storage/docs/storage-classes) for # a Cloud Storage bucket. module StorageClass # Not set. STORAGE_CLASS_UNSPECIFIED = 0 # Best for data that is frequently accessed. STANDARD = 1 # Low-cost storage for data that is accessed less frequently. NEARLINE = 2 # Very low-cost storage for infrequently accessed data. COLDLINE = 3 # Lowest-cost storage for data archiving, online backup, and disaster # recovery. ARCHIVE = 4 end end |
#bucket ⇒ ::String
Returns Required. Immutable. Name of the Cloud Storage bucket to create.
542 543 544 545 546 547 548 549 550 551 552 553 554 555 556 557 558 559 560 561 562 563 564 565 |
# File 'proto_docs/google/cloud/hypercomputecluster/v1beta/hypercompute_cluster.rb', line 542 class NewBucketConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # [Storage class](https://cloud.google.com/storage/docs/storage-classes) for # a Cloud Storage bucket. module StorageClass # Not set. STORAGE_CLASS_UNSPECIFIED = 0 # Best for data that is frequently accessed. STANDARD = 1 # Low-cost storage for data that is accessed less frequently. NEARLINE = 2 # Very low-cost storage for infrequently accessed data. COLDLINE = 3 # Lowest-cost storage for data archiving, online backup, and disaster # recovery. ARCHIVE = 4 end end |
#hierarchical_namespace ⇒ ::Google::Cloud::HypercomputeCluster::V1beta::GcsHierarchicalNamespaceConfig
Returns Optional. Immutable. If set, indicates that the bucket should use hierarchical namespaces.
542 543 544 545 546 547 548 549 550 551 552 553 554 555 556 557 558 559 560 561 562 563 564 565 |
# File 'proto_docs/google/cloud/hypercomputecluster/v1beta/hypercompute_cluster.rb', line 542 class NewBucketConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # [Storage class](https://cloud.google.com/storage/docs/storage-classes) for # a Cloud Storage bucket. module StorageClass # Not set. STORAGE_CLASS_UNSPECIFIED = 0 # Best for data that is frequently accessed. STANDARD = 1 # Low-cost storage for data that is accessed less frequently. NEARLINE = 2 # Very low-cost storage for infrequently accessed data. COLDLINE = 3 # Lowest-cost storage for data archiving, online backup, and disaster # recovery. ARCHIVE = 4 end end |
#storage_class ⇒ ::Google::Cloud::HypercomputeCluster::V1beta::NewBucketConfig::StorageClass
Returns Optional. Immutable. If set, uses the provided storage class as the bucket's default storage class.
Note: The following fields are mutually exclusive: storage_class, autoclass. If a field in that set is populated, all other fields in the set will automatically be cleared.
542 543 544 545 546 547 548 549 550 551 552 553 554 555 556 557 558 559 560 561 562 563 564 565 |
# File 'proto_docs/google/cloud/hypercomputecluster/v1beta/hypercompute_cluster.rb', line 542 class NewBucketConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # [Storage class](https://cloud.google.com/storage/docs/storage-classes) for # a Cloud Storage bucket. module StorageClass # Not set. STORAGE_CLASS_UNSPECIFIED = 0 # Best for data that is frequently accessed. STANDARD = 1 # Low-cost storage for data that is accessed less frequently. NEARLINE = 2 # Very low-cost storage for infrequently accessed data. COLDLINE = 3 # Lowest-cost storage for data archiving, online backup, and disaster # recovery. ARCHIVE = 4 end end |