Class: Google::Cloud::HypercomputeCluster::V1beta::NewFilestoreConfig
- Inherits:
-
Object
- Object
- Google::Cloud::HypercomputeCluster::V1beta::NewFilestoreConfig
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/hypercomputecluster/v1beta/hypercompute_cluster.rb
Overview
When set in a StorageResourceConfig, indicates that a new Filestore instance should be created.
Defined Under Namespace
Instance Attribute Summary collapse
-
#description ⇒ ::String
Optional.
-
#file_shares ⇒ ::Array<::Google::Cloud::HypercomputeCluster::V1beta::FileShareConfig>
Required.
-
#filestore ⇒ ::String
Required.
-
#protocol ⇒ ::Google::Cloud::HypercomputeCluster::V1beta::NewFilestoreConfig::Protocol
Optional.
-
#tier ⇒ ::Google::Cloud::HypercomputeCluster::V1beta::NewFilestoreConfig::Tier
Required.
Instance Attribute Details
#description ⇒ ::String
Returns Optional. Immutable. Description of the instance. Maximum of 2048 characters.
458 459 460 461 462 463 464 465 466 467 468 469 470 471 472 473 474 475 476 477 478 479 480 481 482 483 484 485 486 487 488 489 |
# File 'proto_docs/google/cloud/hypercomputecluster/v1beta/hypercompute_cluster.rb', line 458 class NewFilestoreConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Available [service # tiers](https://cloud.google.com/filestore/docs/service-tiers) for Filestore # instances. module Tier # Not set. TIER_UNSPECIFIED = 0 # Offers expanded capacity and performance scaling capabilities suitable # for high-performance computing application requirements. ZONAL = 4 # Offers features and availability needed for mission-critical, # high-performance computing workloads. REGIONAL = 6 end # File access protocol for Filestore instances. module Protocol # Not set. PROTOCOL_UNSPECIFIED = 0 # NFS 3.0. NFSV3 = 1 # NFS 4.1. NFSV41 = 2 end end |
#file_shares ⇒ ::Array<::Google::Cloud::HypercomputeCluster::V1beta::FileShareConfig>
Returns Required. Immutable. File system shares on the instance. Exactly one file share must be specified.
458 459 460 461 462 463 464 465 466 467 468 469 470 471 472 473 474 475 476 477 478 479 480 481 482 483 484 485 486 487 488 489 |
# File 'proto_docs/google/cloud/hypercomputecluster/v1beta/hypercompute_cluster.rb', line 458 class NewFilestoreConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Available [service # tiers](https://cloud.google.com/filestore/docs/service-tiers) for Filestore # instances. module Tier # Not set. TIER_UNSPECIFIED = 0 # Offers expanded capacity and performance scaling capabilities suitable # for high-performance computing application requirements. ZONAL = 4 # Offers features and availability needed for mission-critical, # high-performance computing workloads. REGIONAL = 6 end # File access protocol for Filestore instances. module Protocol # Not set. PROTOCOL_UNSPECIFIED = 0 # NFS 3.0. NFSV3 = 1 # NFS 4.1. NFSV41 = 2 end end |
#filestore ⇒ ::String
Returns Required. Immutable. Name of the Filestore instance to create, in the
format projects/{project}/locations/{location}/instances/{instance}.
458 459 460 461 462 463 464 465 466 467 468 469 470 471 472 473 474 475 476 477 478 479 480 481 482 483 484 485 486 487 488 489 |
# File 'proto_docs/google/cloud/hypercomputecluster/v1beta/hypercompute_cluster.rb', line 458 class NewFilestoreConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Available [service # tiers](https://cloud.google.com/filestore/docs/service-tiers) for Filestore # instances. module Tier # Not set. TIER_UNSPECIFIED = 0 # Offers expanded capacity and performance scaling capabilities suitable # for high-performance computing application requirements. ZONAL = 4 # Offers features and availability needed for mission-critical, # high-performance computing workloads. REGIONAL = 6 end # File access protocol for Filestore instances. module Protocol # Not set. PROTOCOL_UNSPECIFIED = 0 # NFS 3.0. NFSV3 = 1 # NFS 4.1. NFSV41 = 2 end end |
#protocol ⇒ ::Google::Cloud::HypercomputeCluster::V1beta::NewFilestoreConfig::Protocol
Returns Optional. Immutable. Access protocol to use for all file shares in the instance. Defaults to NFS V3 if not set.
458 459 460 461 462 463 464 465 466 467 468 469 470 471 472 473 474 475 476 477 478 479 480 481 482 483 484 485 486 487 488 489 |
# File 'proto_docs/google/cloud/hypercomputecluster/v1beta/hypercompute_cluster.rb', line 458 class NewFilestoreConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Available [service # tiers](https://cloud.google.com/filestore/docs/service-tiers) for Filestore # instances. module Tier # Not set. TIER_UNSPECIFIED = 0 # Offers expanded capacity and performance scaling capabilities suitable # for high-performance computing application requirements. ZONAL = 4 # Offers features and availability needed for mission-critical, # high-performance computing workloads. REGIONAL = 6 end # File access protocol for Filestore instances. module Protocol # Not set. PROTOCOL_UNSPECIFIED = 0 # NFS 3.0. NFSV3 = 1 # NFS 4.1. NFSV41 = 2 end end |
#tier ⇒ ::Google::Cloud::HypercomputeCluster::V1beta::NewFilestoreConfig::Tier
Returns Required. Immutable. Service tier to use for the instance.
458 459 460 461 462 463 464 465 466 467 468 469 470 471 472 473 474 475 476 477 478 479 480 481 482 483 484 485 486 487 488 489 |
# File 'proto_docs/google/cloud/hypercomputecluster/v1beta/hypercompute_cluster.rb', line 458 class NewFilestoreConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Available [service # tiers](https://cloud.google.com/filestore/docs/service-tiers) for Filestore # instances. module Tier # Not set. TIER_UNSPECIFIED = 0 # Offers expanded capacity and performance scaling capabilities suitable # for high-performance computing application requirements. ZONAL = 4 # Offers features and availability needed for mission-critical, # high-performance computing workloads. REGIONAL = 6 end # File access protocol for Filestore instances. module Protocol # Not set. PROTOCOL_UNSPECIFIED = 0 # NFS 3.0. NFSV3 = 1 # NFS 4.1. NFSV41 = 2 end end |