Class: Google::Cloud::HypercomputeCluster::V1beta::NewLustreConfig
- Inherits:
-
Object
- Object
- Google::Cloud::HypercomputeCluster::V1beta::NewLustreConfig
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/hypercomputecluster/v1beta/hypercompute_cluster.rb
Overview
When set in a StorageResourceConfig, indicates that a new Managed Lustre instance should be created.
Instance Attribute Summary collapse
-
#capacity_gb ⇒ ::Integer
Required.
-
#description ⇒ ::String
Optional.
-
#filesystem ⇒ ::String
Required.
-
#lustre ⇒ ::String
Required.
Instance Attribute Details
#capacity_gb ⇒ ::Integer
Returns Required. Immutable. Storage capacity of the instance in gibibytes (GiB). Allowed values are between 18000 and 7632000.
628 629 630 631 |
# File 'proto_docs/google/cloud/hypercomputecluster/v1beta/hypercompute_cluster.rb', line 628 class NewLustreConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#description ⇒ ::String
Returns Optional. Immutable. Description of the Managed Lustre instance. Maximum of 2048 characters.
628 629 630 631 |
# File 'proto_docs/google/cloud/hypercomputecluster/v1beta/hypercompute_cluster.rb', line 628 class NewLustreConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#filesystem ⇒ ::String
Returns Required. Immutable. Filesystem name for this instance. This name is used by client-side tools, including when mounting the instance. Must be 8 characters or less and can only contain letters and numbers.
628 629 630 631 |
# File 'proto_docs/google/cloud/hypercomputecluster/v1beta/hypercompute_cluster.rb', line 628 class NewLustreConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#lustre ⇒ ::String
Returns Required. Immutable. Name of the Managed Lustre instance to create, in the
format projects/{project}/locations/{location}/instances/{instance}.
628 629 630 631 |
# File 'proto_docs/google/cloud/hypercomputecluster/v1beta/hypercompute_cluster.rb', line 628 class NewLustreConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |