Class: Google::Cloud::HypercomputeCluster::V1beta::NewNetworkConfig
- Inherits:
-
Object
- Object
- Google::Cloud::HypercomputeCluster::V1beta::NewNetworkConfig
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/hypercomputecluster/v1beta/hypercompute_cluster.rb
Overview
When set in a NetworkResourceConfig, indicates that a new network should be created.
Instance Attribute Summary collapse
-
#description ⇒ ::String
Optional.
-
#network ⇒ ::String
Required.
Instance Attribute Details
#description ⇒ ::String
Returns Optional. Immutable. Description of the network. Maximum of 2048 characters.
307 308 309 310 |
# File 'proto_docs/google/cloud/hypercomputecluster/v1beta/hypercompute_cluster.rb', line 307 class NewNetworkConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#network ⇒ ::String
Returns Required. Immutable. Name of the network to create, in the format
projects/{project}/global/networks/{network}.
307 308 309 310 |
# File 'proto_docs/google/cloud/hypercomputecluster/v1beta/hypercompute_cluster.rb', line 307 class NewNetworkConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |