Class: Google::Cloud::HypercomputeCluster::V1beta::Orchestrator
- Inherits:
-
Object
- Object
- Google::Cloud::HypercomputeCluster::V1beta::Orchestrator
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/hypercomputecluster/v1beta/hypercompute_cluster.rb
Overview
The component responsible for scheduling and running workloads on the cluster as well as providing the user interface for interacting with the cluster at runtime.
Instance Attribute Summary collapse
Instance Attribute Details
#slurm ⇒ ::Google::Cloud::HypercomputeCluster::V1beta::SlurmOrchestrator
Returns Optional. If set, indicates that the cluster should use Slurm as the orchestrator.
786 787 788 789 |
# File 'proto_docs/google/cloud/hypercomputecluster/v1beta/hypercompute_cluster.rb', line 786 class Orchestrator include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |