Class: Google::Cloud::HypercomputeCluster::V1beta::StorageResource
- Inherits:
-
Object
- Object
- Google::Cloud::HypercomputeCluster::V1beta::StorageResource
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/hypercomputecluster/v1beta/hypercompute_cluster.rb
Overview
A resource representing a form of persistent storage that is accessible to compute resources in the cluster.
Instance Attribute Summary collapse
-
#bucket ⇒ ::Google::Cloud::HypercomputeCluster::V1beta::BucketReference
Reference to a Google Cloud Storage bucket.
-
#config ⇒ ::Google::Cloud::HypercomputeCluster::V1beta::StorageResourceConfig
Required.
-
#filestore ⇒ ::Google::Cloud::HypercomputeCluster::V1beta::FilestoreReference
Reference to a Filestore instance.
-
#lustre ⇒ ::Google::Cloud::HypercomputeCluster::V1beta::LustreReference
Reference to a Managed Lustre instance.
Instance Attribute Details
#bucket ⇒ ::Google::Cloud::HypercomputeCluster::V1beta::BucketReference
Returns Reference to a Google Cloud Storage bucket. Populated if and only if the storage resource was configured to use Google Cloud Storage.
Note: The following fields are mutually exclusive: bucket, filestore, lustre. If a field in that set is populated, all other fields in the set will automatically be cleared.
355 356 357 358 |
# File 'proto_docs/google/cloud/hypercomputecluster/v1beta/hypercompute_cluster.rb', line 355 class StorageResource include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#config ⇒ ::Google::Cloud::HypercomputeCluster::V1beta::StorageResourceConfig
Returns Required. Immutable. Configuration for this storage resource, which describes how it should be created or imported. This field only controls how the storage resource is initially created or imported. Subsequent changes to the storage resource should be made via the resource's API and will not be reflected in the configuration.
355 356 357 358 |
# File 'proto_docs/google/cloud/hypercomputecluster/v1beta/hypercompute_cluster.rb', line 355 class StorageResource include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#filestore ⇒ ::Google::Cloud::HypercomputeCluster::V1beta::FilestoreReference
Returns Reference to a Filestore instance. Populated if and only if the storage resource was configured to use Filestore.
Note: The following fields are mutually exclusive: filestore, bucket, lustre. If a field in that set is populated, all other fields in the set will automatically be cleared.
355 356 357 358 |
# File 'proto_docs/google/cloud/hypercomputecluster/v1beta/hypercompute_cluster.rb', line 355 class StorageResource include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#lustre ⇒ ::Google::Cloud::HypercomputeCluster::V1beta::LustreReference
Returns Reference to a Managed Lustre instance. Populated if and only if the storage resource was configured to use Managed Lustre.
Note: The following fields are mutually exclusive: lustre, filestore, bucket. If a field in that set is populated, all other fields in the set will automatically be cleared.
355 356 357 358 |
# File 'proto_docs/google/cloud/hypercomputecluster/v1beta/hypercompute_cluster.rb', line 355 class StorageResource include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |