Class: Google::Cloud::HypercomputeCluster::V1beta::StorageResourceConfig
- Inherits:
-
Object
- Object
- Google::Cloud::HypercomputeCluster::V1beta::StorageResourceConfig
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/hypercomputecluster/v1beta/hypercompute_cluster.rb
Overview
Describes how a storage resource should be initialized. Each storage resource can either be imported from an existing Google Cloud resource or initialized when the cluster is created.
Instance Attribute Summary collapse
-
#existing_bucket ⇒ ::Google::Cloud::HypercomputeCluster::V1beta::ExistingBucketConfig
Optional.
-
#existing_filestore ⇒ ::Google::Cloud::HypercomputeCluster::V1beta::ExistingFilestoreConfig
Optional.
-
#existing_lustre ⇒ ::Google::Cloud::HypercomputeCluster::V1beta::ExistingLustreConfig
Optional.
-
#new_bucket ⇒ ::Google::Cloud::HypercomputeCluster::V1beta::NewBucketConfig
Optional.
-
#new_filestore ⇒ ::Google::Cloud::HypercomputeCluster::V1beta::NewFilestoreConfig
Optional.
-
#new_lustre ⇒ ::Google::Cloud::HypercomputeCluster::V1beta::NewLustreConfig
Optional.
Instance Attribute Details
#existing_bucket ⇒ ::Google::Cloud::HypercomputeCluster::V1beta::ExistingBucketConfig
Returns Optional. Immutable. If set, indicates that an existing Cloud Storage bucket should be imported.
Note: The following fields are mutually exclusive: existing_bucket, new_filestore, existing_filestore, new_bucket, new_lustre, existing_lustre. If a field in that set is populated, all other fields in the set will automatically be cleared.
430 431 432 433 |
# File 'proto_docs/google/cloud/hypercomputecluster/v1beta/hypercompute_cluster.rb', line 430 class StorageResourceConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#existing_filestore ⇒ ::Google::Cloud::HypercomputeCluster::V1beta::ExistingFilestoreConfig
Returns Optional. Immutable. If set, indicates that an existing Filestore instance should be imported.
Note: The following fields are mutually exclusive: existing_filestore, new_filestore, new_bucket, existing_bucket, new_lustre, existing_lustre. If a field in that set is populated, all other fields in the set will automatically be cleared.
430 431 432 433 |
# File 'proto_docs/google/cloud/hypercomputecluster/v1beta/hypercompute_cluster.rb', line 430 class StorageResourceConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#existing_lustre ⇒ ::Google::Cloud::HypercomputeCluster::V1beta::ExistingLustreConfig
Returns Optional. Immutable. If set, indicates that an existing Managed Lustre instance should be imported.
Note: The following fields are mutually exclusive: existing_lustre, new_filestore, existing_filestore, new_bucket, existing_bucket, new_lustre. If a field in that set is populated, all other fields in the set will automatically be cleared.
430 431 432 433 |
# File 'proto_docs/google/cloud/hypercomputecluster/v1beta/hypercompute_cluster.rb', line 430 class StorageResourceConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#new_bucket ⇒ ::Google::Cloud::HypercomputeCluster::V1beta::NewBucketConfig
Returns Optional. Immutable. If set, indicates that a new Cloud Storage bucket should be created.
Note: The following fields are mutually exclusive: new_bucket, new_filestore, existing_filestore, existing_bucket, new_lustre, existing_lustre. If a field in that set is populated, all other fields in the set will automatically be cleared.
430 431 432 433 |
# File 'proto_docs/google/cloud/hypercomputecluster/v1beta/hypercompute_cluster.rb', line 430 class StorageResourceConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#new_filestore ⇒ ::Google::Cloud::HypercomputeCluster::V1beta::NewFilestoreConfig
Returns Optional. Immutable. If set, indicates that a new Filestore instance should be created.
Note: The following fields are mutually exclusive: new_filestore, existing_filestore, new_bucket, existing_bucket, new_lustre, existing_lustre. If a field in that set is populated, all other fields in the set will automatically be cleared.
430 431 432 433 |
# File 'proto_docs/google/cloud/hypercomputecluster/v1beta/hypercompute_cluster.rb', line 430 class StorageResourceConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#new_lustre ⇒ ::Google::Cloud::HypercomputeCluster::V1beta::NewLustreConfig
Returns Optional. Immutable. If set, indicates that a new Managed Lustre instance should be created.
Note: The following fields are mutually exclusive: new_lustre, new_filestore, existing_filestore, new_bucket, existing_bucket, existing_lustre. If a field in that set is populated, all other fields in the set will automatically be cleared.
430 431 432 433 |
# File 'proto_docs/google/cloud/hypercomputecluster/v1beta/hypercompute_cluster.rb', line 430 class StorageResourceConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |